# SIENA 1.0.0 Release
### Efficient entity annotation tool for Sinhala, English, or Sinhala-English code-switched text corpora.
## Features
- Allows annotating both Sinhala and English textual data
- Fully compatible with Rasa 2.8.x NLU training data files
- Allows exporting annotated NLU YAML files
- Able to auto annotate entities efficiently based on novel NLP techniques including reverse-stemming
- Easy to use SIENA CLI that can spin up a GUI server, locally
- Read more on [docs](https://siena-nlp.github.io)

## Ongoing Research
- Concurrent entity tagging for multiple users
- Import/Export support for non-Rasa NLU data files and text corpora

## Known Issues
- Support for Rasa versions other than 2.8.x is under ongoing development
- Benchmark tests are in progress

📒 Docs: https://siena-nlp.github.io  
📦 PyPi: https://pypi.org/project/siena/1.0.0/  
🪵 Full Changelog: Refer the relevant GitHub branch (v1.0.0) 
